#
# spec file for package asciidoc
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           asciidoc
Version:        8.6.10
Release:        2.1
Summary:        Text-Based Document Generation
License:        GPL-2.0+
Group:          Development/Tools/Doc Generators
Url:            http://asciidoc.org
Source0:        https://github.com/%{name}/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         asciidoc.version.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  python2 >= 2.3
BuildRequires:  python2-xml
Requires:       docbook-xsl-stylesheets
Requires:       python2 >= 2.3
Requires:       python2-xml
Recommends:     dblatex
# a2x needs /usr/bin/xsltproc
Recommends:     libxslt
BuildArch:      noarch

%description
AsciiDoc is a text document format for writing short documents,
articles, books, and UNIX man pages. AsciiDoc files can be translated
to HTML and DocBook markups using the asciidoc command.

%package examples
Summary:        Examples and Documents for asciidoc
Group:          Development/Tools/Doc Generators

%description examples
This package contains examples and documents of asciidoc.

%prep
%setup -q
%patch0 -p1

%build
sed -i "s|python|python2|g" Makefile.in
autoreconf -fi
%configure

%install
%make_install

# Strip .py extension from binaries
pushd %{buildroot}%{_bindir}
	mv %{name}.py %{name}
	mv a2x.py a2x
popd

# install vim files
mkdir -p %{buildroot}%{_datadir}/vim/site/{syntax,ftdetect}
install -m 0644 vim/syntax/* %{buildroot}%{_datadir}/vim/site/syntax

%files
%config %{_sysconfdir}/%{name}
%{_bindir}/%{name}
%{_bindir}/a2x
%{_datadir}/vim
%{_mandir}/man1/*
%doc README.asciidoc BUGS.txt CHANGELOG.txt COPYRIGHT

%files examples
%doc doc examples

%changelog
* Tue Nov  7 2017 mpluskal@suse.com
- Explicitly use python2 (fate#323526)
* Fri Oct  6 2017 bwiedemann@suse.com
- Re-add documentation
* Wed Oct  4 2017 olaf@aepfle.de
- Remove asciidoc version from generated files with asciidoc.version.patch
  The version causes unneeded republish of pkgs that make use
  of asciidoc
* Sun Oct  1 2017 aavindraa@gmail.com
- Update to 8.6.10
  * Improve reproducibility of builds (e.g. support SOURCE_DATE_EPOCH)
  * SVG output support
  * documentation and translations
- Lint spec file
- Remove asciidoc-change-Last-Updated-field.patch
  * merged in https://github.com/asciidoc/asciidoc/pull/9
* Fri Jul  7 2017 matthias.gerstner@suse.com
- added themes directory for installing the other available themes shipped
  with asciidoc. Makes the "-a theme=volnitsky" and "-a theme=flask" switches
  work.
* Thu Sep  1 2016 olaf@aepfle.de
- Adding the ability to change "Last Updated" field
  ... to reduce build-compare noise in git.rpm
  asciidoc-change-Last-Updated-field.patch
* Fri Mar  6 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Remove asciidoc-vim-fix.diff
- Update to 8.6.9
  * html5, xhtml11 and slidy outputs now wrap pre element contents at
    right margin (see
    [1]https://groups.google.com/group/asciidoc/browse_thread/thread/98
    77a316b7a47309).
  * Vim syntax file: highlight line breaks in lists (patch submitted by
    Alex Efros). See
    [2]https://groups.google.com/group/asciidoc/browse_thread/thread/51
    45e4c0b65cde0a).
  * Vim syntax file: fixed highlighting of lines with spaces preceding
    an indented paragraph. See
    [3]https://groups.google.com/group/asciidoc/browse_thread/thread/51
    45e4c0b65cde0a
  * Vim syntax file: dropped ) from list of illegal characters
    following opening quote. See
    [4]https://groups.google.com/group/asciidoc/browse_thread/thread/1a
    60eb4507a0555f/264c39c6a89fc7a0
  * Added + intrinsic attribute. See
    [5]http://code.google.com/p/asciidoc/issues/detail?id=14
  * Allow tabsize=0 in configuration file. See
    [6]https://groups.google.com/group/asciidoc/browse_thread/thread/c8
    8457020288ce1d
  * Removed wordpress backend into the blogpost project (where it
    belongs) as an AsciiDoc backend plugin.
  * Added HTML5 footer badges.
  * Added favicon to AsciiDoc website.
  * Changed AsciiDoc website domain to asciidoc.org.
  * Vim syntax file: closing quote character cannot be immediately
    followed by same closing quote character.
  * Documentation updates.
  * If admonition icons are embedded using the Data URI Scheme and the
    icons directory is undefined or does not exist then the iconsdir
    attribute is set to the location of the icons installed in the
    AsciiDoc configuration directory.
  * Updated ./stylesheets/pygments.css from pygments 1.4.
  * HTML backends: Align inline images to text-bottom.
  * html4 backend: Added hr attribute to make the inter-section
    horizontal ruler element optional.
  * Documented Callout lists cannot be used within tables. See:
    [7]https://groups.google.com/group/asciidoc/browse_thread/thread/26
    8f9b46ebc192d3
  * Removed Vim related stuff from the installer makefile. See:
    [8]https://groups.google.com/group/asciidoc/browse_thread/thread/75
    3a52b2af85fcfc/04c9091b0856fc13 and
    [9]https://groups.google.com/group/asciidoc/browse_thread/thread/cd
    07629fa7a53fb3
  * Dropped vim/ftdetect/asciidoc_filetype.vim from distribution, the
    file detection was broken and the default settings satisfied noone.
  * Vim syntax highlighter: increase sync backtracking to catch changes
    to large block elements.
  * Added Romanian language configuration file. Contributed by Vitalie
    Lazu. See
    [10]https://groups.google.com/group/asciidoc/browse_thread/thread/2
    fe14a10dbf20d20/27726e7e13f7bfc7?lnk=gst&q=romanian#27726e7e13f7bfc
    7
  * Added ruler and line-break outputs to HTML Help outputs. Patch
    submitted by DonM. See
    [11]https://groups.google.com/group/asciidoc/browse_thread/thread/b
    131d0155eccd73e
  * Added Czech language configuration file. Contributed by Petr Klíma.
  * html4 backend: allow embedded images and icons (data-uri
    attribute).
  * html4 backend: table and example block caption place at bottom for
    consistency.
  * html4 backend: dropped border around example block.
  * html4 backend: cellpaddings made equal to 4 for consistency.
  * Vim syntax highligher: Highlight closing OpenBlock delimiter when
    it immediately follows a list.
  * Updated html5 backend (previous commit was xhtml11 only). See:
    [12]https://groups.google.com/group/asciidoc/browse_thread/thread/d
    bdfaf838f93e020
  * Embedded data-uri images now figure file mimetype from file
    contents rather than the file extension. Patch submitted by Lex
    Trotman. See:
    [13]https://groups.google.com/group/asciidoc/browse_thread/thread/d
    bdfaf838f93e0
* Wed Mar 20 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Sat Oct 27 2012 toms@opensuse.org
- updated to version 8.6.8 (2012-07-17):
  * Added full complement of styles to Open Blocks and Normal Paragraphs — 
  those with a minimalist bent could construct virtually any document
  using just Title, Normal Paragraph and Open Block syntaxes.
  * See details in
  http://www.methods.co.nz/asciidoc/CHANGELOG.html
- previous version 8.6.7 (2012-03-17):
  * No major enhancements but quite a few bug fixes which, among other
  things, fixes Jython compatibility and improves Windows compatibility.
- SPEC file:
  * Regenerated asciidoc-vim-fix.diff
* Mon Nov  7 2011 mmarek@suse.cz
- Add missing dependency on python-xml.
* Fri Oct 28 2011 yar@sibnet.ru
- updated to version 8.6.6:
  * New html5 backend.
  * Enhanced plugin system.
  * See details in
  http://www.methods.co.nz/asciidoc/CHANGELOG.html
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Mon Jul 20 2009 tiwai@suse.de
- updated to version 8.4.5:
  * multiple manpage names are now handled correctly when generating
  DocBook output
  * The article and book document header can now include a revision
  remark
  * French, German, Hungarian and Russian language file
  contributions
  * See details in
  http://www.methods.co.nz/asciidoc/CHANGELOG.html
* Thu May  7 2009 tiwai@suse.de
- updated to version 8.4.4:
  See http://www.methods.co.nz/asciidoc/CHANGELOG.html for details
* Fri Jan 30 2009 tiwai@suse.de
- Additional error message about missing package in a2x
* Wed Jan 21 2009 tiwai@suse.de
- Don't require fop and libxslt but use recommends as asciidoc
  itself can work without these packages.  They are needed only
  for a2x for some file types like PDF.
  This may break the build of some packages; in such a case, just
  add either fop or dblatex to buildrequires.
* Thu Jan  8 2009 bbrunner@suse.de
- updated to version 8.3.3
  * The broken and confusing numeration and numeration2 numbered list
  attributes have been dropped, use the style attribute instead.
  * SidebarBlock element can be rendered with an abstract style.
  * (see CHANGELOG)
* Sun Nov  2 2008 bwalle@suse.de
- Call Python with -Wignore::DeprecationWarning to hide deprecation
  warnings from the user.
* Mon Jul 28 2008 tiwai@suse.de
- add requirement of xsltproc binary (bnc#410692)
* Tue Jul 22 2008 bwalle@suse.de
- Suppression of manpage references list now works again.
  (http://hg.sharesource.org/asciidoc/rev/eb3a27e2a482)
* Tue Jul  8 2008 bwalle@suse.de
- install dblatex files
* Fri Jul  4 2008 bwalle@suse.de
- updated to version 8.2.7
  * Added dvi, ps and tex output format options to a2x(1).
  * Added —dblatex option to a2x(1) so dblatex(1) can be used to
    generate PDFs.
  * Added custom dblatex(1) configuration files (in distribution
    ./dblatex directory) which are used by a2x(1).
  * dblatex(1) is now used to generate the distributed PDF version
    of the AsciiDoc User Guide.
  * If you don't need a customized the link caption you can enter
    the http, https, ftp, file URLs and email addresses without
    any special macro syntax.
  * Highlighted source code paragraphs have been implemented.
  * The source highlighter and music filter syntax has changed
  * QuoteBlocks now have a verse style
  * It is no up to the DocBook processor to highlight source code
    syntax
  * scaledwidth and align attributes have been added to the image
    macro
  * Added a2x(1) —fop-opts=FOP_OPTS option
  * Added a2x(1) —dblatex-opts=DBLATEX_OPTS
  * Added Mikhail Yakshin's FOP 0.95 patch
  * The User Guide has been updated
  * Fixed stylesheets/xhtml11-manpage.css not being included when
    linkcss attribute was used
  * Configuration file *-style attributes are now dumped correctly
  * Fixed FAILED: malformed section entry LaTeX backend error
* Tue Jun 10 2008 tiwai@suse.de
- updated to version 8.2.6:
  * Bug fixes since the last release plus a code cleanup and a
    few minor additions and changes.
* Mon May  5 2008 tiwai@suse.de
- added missing requires to docbook-xsl-stylesheets (bnc#386512)
* Wed Jan 30 2008 tiwai@suse.de
- fix fop.extensions in a2x pdf creation (bnc#353527)
* Fri Jan 25 2008 tiwai@suse.de
- fix a build error about vim directory
* Thu Jan 24 2008 tiwai@suse.de
- install vim files (#353528)
* Mon Jan 14 2008 tiwai@suse.de
- add requirement to fop, fix the fop command name in a2x
  (#353527)
* Tue Jan  8 2008 tiwai@suse.de
- updated to version 8.2.5:
  * fixes couple of bugs in 8.2.4, no new features
* Thu Nov 15 2007 tiwai@suse.de
- updated to version 8.2.2-8.2.4:
  * improvements on lang attribute handling
  * fixed spurious warning in Python 2.6
  * auto-generated section IDs
  * changed format of {localdate} attribute to ISO 8601 (%%Y-%%m-%%d).
  * added abc2ly —beams=None option
  * XHTML level 2 section headings are now styled with an
    underlining border
  * XHTML links to AsciiDoc title elements are now implemented
    with title ID attributes
  * multi-word first, middle and last names can be entered in
    the header author line
  * the nested inline macros restriction has now been lifted
  * help topic names can be shortened
  * added {two_colons} and {two_semicolons} attributes
  * LaTeXMathML capability has been added
  * added an —attribute=ATTRIBUTE option to a2x(1)
  * image block and inline macros prepend optional
    {imagesdir} attribute to image link targets
- split doc and examples to separate sub-package to make rpmlint
  happy
* Tue May 22 2007 tiwai@suse.de
- updated to version 8.2.1:
  * VIM syntax highlighter
  * Labeled list definitions have been tightened
  * Added toclevel attribute (1..4)
  * Added a listindex attribute
  * The single line titles syntax now accepts trailing suffixes
  * An end of line backslash performs line continuation for
    horizontal labeled list items.
  * The Revision line now accommodates Subversion $Id markers
  * a2x(1) option —skip-asciidoc
  * Defaults to appropriate format if -format isn't given.
* Mon Apr  2 2007 tiwai@suse.de
- updated to version 8.1.0:
  * AsciiDoc generated XHTML documents now display as table of
    contents if the toc attribute is defined.
  * A music filter is included.
  * Conditionally redefined subscript and superscripting so they
    use the old replacements mechanism when asciidoc7compatible
    is defined rather than the asciidoc 8 default unconstrained
    quoting.
  * Added {verbose} intrinsic attribute.
  * Added {outdir} intrinsic attribute.
  * Renamed {docdir} intrinsic attribute to unambiguous`{indir}
  * If asciidoc(1) outputs to stdout then instrinsic attribute
    {docname} is extracted from the input file name.
* Thu Nov 23 2006 tiwai@suse.de
- Add missing a2x and other config files (#223299).
* Thu Oct 12 2006 tiwai@suse.de
- updated to version 8.0.0:
  * An experimental LaTeX backend
  * Unconstrained quoting allows quoting to appear anywhere in inline text
  * a2x toolchain wrapper script can generate Open Document text files
  * More on CHANGELOG
* Mon May 15 2006 tiwai@suse.de
- updated to version 7.1.2.
  * a2x toolchain wrapper
  * ASCIIMathML support
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 tiwai@suse.de
- updated to version 7.0.4.
* Fri Jul  1 2005 tiwai@suse.de
- fixed norootforbuild.
* Fri Jun 24 2005 tiwai@suse.de
- initial version: 7.0.1.
